==> v4_navigation_engine-0.1.30.tar.gz: ios/Classes/NavigationV4/View/MyNavigationView+InitFunctions.swift <==
//
//  MyNavigationView+Functions.swift
//  NavigationUI
//
//  Created by Hassine on 04/06/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//

import MapboxCoreNavigation


import CoreLocation
import Speech
import MapboxDirections
import LiquidFloatingActionButton
import SnapKit
import MaterialComponents.MaterialButtons
import AVFoundation

extension MyNavigationView 
{
    func initUI() -> Void {
        DispatchQueue.main.async {
            
            //maneuverView
            self.maneuverView.primaryColor                          = UIColor.white
            self.maneuverView.secondaryColor                        = UIColor.white
            self.maneuverView.backgroundColor                       = .clear
            
            //primaryInstruction_lbl
            self.primaryInstruction_lbl.primaryInstructionStyle()
            self.primaryInstruction_lbl.numberOfLines               = 2;
            self.primaryInstruction_lbl.minimumScaleFactor          = 0.4
            self.primaryInstruction_lbl.adjustsFontSizeToFitWidth   = true;
            
            //distanceInstruction_lbl
            self.distanceInstruction_lbl.distanceInstructionStyle()

            //gps_lbl
            self.gpsSignl_lbl.title3Style()
            
            //containerBannerView
            self.containerBanner_view.layer.cornerRadius = 30
            self.containerBanner_view.backgroundColor               = Style.shared.primaryColor
            self.statusBarBanner_view.backgroundColor               = Style.shared.primaryColor
            
            //containerSeconcBannerView
            self.containerSecondBanner_view.layer.cornerRadius      = 30
            
            //containerMap_view
            self.containerMap_view.backgroundColor                  = Style.shared.backgroundColor
            
            // containerView_view
            self.containerView_view.backgroundColor                 = Style.shared.backgroundColor
            
            // informationsContainer_view
            self.informationsContainer_view.backgroundColor         = Style.shared.backgroundColor
            self.informationsContainer_view.layer.cornerRadius      = 30
            
            // pauseRun_slideBtn
            self.pauseRun_slideBtn.myView                           = self.dotSlide_view
            self.pauseRun_slideBtn.buttonUnlockedText               = "UNLOCKED"
            self.pauseRun_slideBtn.delegate                         = self
            
            //dotSlide_view
            self.dotSlide_view.layer.cornerRadius                   = 40
            self.dotSlide_view.layer.borderWidth                    = 15
            self.dotSlide_view.backgroundColor                      = Style.shared.slideDotColor
            self.dotSlide_view.layer.borderColor                    = Style.shared.slideDotBorderColor.cgColor//
            self.dotSlide_view.isUserInteractionEnabled             = false
            
            // dotIcon_imageView
            self.dotIcon_imageView.image                            = Bundle.assets.image(named: "pause_icon")
            
            //progressRouteIcon_imageView
            self.progressRouteIcon_imageView.image                  = Bundle.assets.image(named: "thumbeilslider")
            
            // progressRoute_ProgressBar
            self.progressRoute_ProgressBar.trackTintColor           = Style.shared.slideBackgroundColor
            
            // Labels
            self.timerValue_lbl.timerCradStyle()
            
            self.speedValue_lbl.valueCradStyle()
            self.distanceValue_lbl.valueCradStyle()
            
            self.speedTitle_lbl.titleCradStyle()
            self.distanceTitle_lbl.titleCradStyle()
            
            //center_btn
            self.center_btn.layer.cornerRadius                      = 30
            self.center_btn.backgroundColor                         = UIColor.white
            
            if self.measurementSystem == .metric
            {
                self.speedTitle_lbl.text                            = "km/h"
                self.distanceTitle_lbl.text                         = "km"
            }
            else if self.measurementSystem == .imperial
            {
                self.speedTitle_lbl.text                            = "mph"
                self.distanceTitle_lbl.text                         = "mi"
            }
            self.initFloatingButtons()
        }
        
    }

    func initFloatingButtons() -> Void
    {
        let customCellFactory: (String,String) -> LiquidFloatingCell = { (iconName,title) in
            let cell = CustomCell(icon: Bundle.assets.image(named: iconName)!, name: title)
            return cell
        }

        cellsFloatingButton.append(customCellFactory("ic_sound_on", "Audio guide: activated"))
        cellsFloatingButton.append(customCellFactory("sms_ic", "Emergency SMS"))
        //cellsFloatingButton.append(cellFactory("ic_place"))

        

        let _: (CGRect, LiquidFloatingActionButtonAnimateStyle) -> LiquidFloatingActionButton = { (frame, style) in
            let floatingActionButton = CustomDrawingActionButton(frame: frame)
            floatingActionButton.animateStyle = style
            floatingActionButton.delegate = self
            floatingActionButton.color = UIColor.white
            return floatingActionButton
        }

        DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+1) {
            let createButton: (CGRect, LiquidFloatingActionButtonAnimateStyle) -> LiquidFloatingActionButton = { (frame, style) in
                let floatingActionButton = CustomDrawingActionButton(frame: frame)
                floatingActionButton.animateStyle = style
                floatingActionButton.dataSource = self
                floatingActionButton.delegate = self
                floatingActionButton.color = Style.shared.primaryColor
                return floatingActionButton
            }
            let floatingFrame = CGRect(x: self.containerMap_view.frame.width - 56 - 16, y: self.containerMap_view.frame.height - 56 - 16 - 30, width: 56, height: 56)
            
            self.more_btn = createButton(floatingFrame, .up)
            
            let image = UIImage(named: "more_ic")
            self.more_btn.image = image
            self.containerMap_view.addSubview(self.more_btn)
        }

        

         if let stringUrl = routeInformation?.city?.spotifyURL {
            if URL.init(string: stringUrl) != nil
                       {
 
                        DispatchQueue.main.async {
                            self.fab = MDCFloatingButton()
                            self.fab?.frame =  CGRect(x: self.containerMap_view.frame.width - 45 - 16 , y: self.containerMap_view.frame.height - 45 - 35 - 65 , width: 45, height: 45)
                            self.fab?.inkColor = Style.shared.primaryColor
                            self.fab?.backgroundColor = .white
                            self.fab?.tintColor = Style.shared.primaryColor
                            self.fab?.setImage(UIImage(named: "ic_music"), for: .normal)
                            self.fab?.addTarget(self, action: #selector(self.sponsor_action(_:)), for: .touchUpInside)
                            self.containerMap_view.addSubview(self.fab!)
                        }
            }
        }
    }
    
    @objc func sponsor_action(_ sender: UIButton) {
        showSpotify()
    }
    
    func initMap() -> Void {
        DispatchQueue.main.async {
            if let location = LocationService.shared.getCurrentLocation()
            {
                self.mapView_map.setCenter(location.coordinate, zoomLevel: 17, direction: 0, animated: false)
            }
            self.mapView_map.delegate                               = self
            self.mapView_map.compassView.isHidden                   = true
            self.mapView_map.logoView.isHidden                      = true
            self.mapView_map.attributionButton.isHidden             = true
            self.mapView_map.showsUserLocation                      = true
            self.mapView_map.tracksUserCourse                       = false
            self.mapView_map.userTrackingMode                       = .followWithHeading
        }
    }
    
    func initLocationManager() -> Void {
        LocationService.shared.locationManager.delegate             = self
        LocationService.shared.locationManager.requestWhenInUseAuthorization()
        LocationService.shared.locationManager.activityType         = .fitness
        LocationService.shared.locationManager.desiredAccuracy      = 10
        LocationService.shared.locationManager.distanceFilter = kCLDistanceFilterNone
        LocationService.shared.locationManager.startUpdatingLocation()
        LocationService.shared.locationManager.startMonitoringSignificantLocationChanges()
        
    }
    
    func initMeasurementSystem() -> Void{
        if measurementSystem == .imperial
        {
            NavigationSettings.shared.distanceUnit                  = .mile
        }
        else if measurementSystem == .metric
        {
            NavigationSettings.shared.distanceUnit                  = .kilometer
        }
    }
    
    func initLanguageRessources()
    {
        if  let arraySaved = UserDefaults.standard.array(forKey: "languagePreferredOrder") as! Array<String>? {
            languageRessource = LanguageRessource.init(languageSelected: arraySaved.first!)
        }
        else
        {
            languageRessource = LanguageRessource.init(languageSelected: MyUtils.getLanguage())
        }
    }
    
    func initAudioSpeech() -> Void {
        PlayerManager.shared.configureSession(lang:  languageAndCountry)
    }
    
    func initNavigation(userRoute:Route) -> Void {

        if navigationFinished  == false
        {
        navigationService = MapboxNavigationService.init(route: userRoute)
        RouteControllerProactiveReroutingInterval = 500
        navigationService.router.reroutesProactively = false
        navigationService.delegate = self
        initVoiceController()
        resumeNotifications()
        navigationService.start()
        }
    }
    
    
    
    func initVoiceController() -> Void {
        voiceController                                             = CustomVoiceController(navigationService: navigationService)
        self.voiceController?.initNotification()
    }
    
    func deinitNavigation()
    {
        if self.navigationService != nil
        {
            self.navigationService.stop()
        }
        self.voiceController = nil
        self.suspendNotifications()
       // PlayerManager.shared.stopPlayer()
        navigationFinished  = true
        self.voiceController?.stopPlayer()
        PlayerManager.shared.stopSynt()
        DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+1) {
            PlayerManager.shared.playSynt(description: self.languageRessource.endRoute)
        }
        
    }
    
    
    func stopNavigation() -> Void {
        suspendNotifications()
        if navigationService != nil
        {
            navigationService.stop()
            navigationService.delegate = nil
        }

        voiceController = nil
        navigationService = nil
        PlayerManager.shared.speechSynthesizer.stopSpeaking(at: AVSpeechBoundary.immediate)
        wayToRoute = nil
    }
    
}

==> v4_navigation_engine-0.1.31.tar.gz: ios/Classes/NavigationV4/View/MyNavigationView+InitFunctions.swift <==
//
//  MyNavigationView+Functions.swift
//  NavigationUI
//
//  Created by Hassine on 04/06/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//

import MapboxCoreNavigation


import CoreLocation
import Speech
import MapboxDirections
import LiquidFloatingActionButton
import SnapKit
import MaterialComponents.MaterialButtons
import AVFoundation

extension MyNavigationView 
{
    func initUI() -> Void {
        DispatchQueue.main.async {
            
            //maneuverView
            self.maneuverView.primaryColor                          = UIColor.white
            self.maneuverView.secondaryColor                        = UIColor.white
            self.maneuverView.backgroundColor                       = .clear
            
            //primaryInstruction_lbl
            self.primaryInstruction_lbl.primaryInstructionStyle()
            self.primaryInstruction_lbl.numberOfLines               = 2;
            self.primaryInstruction_lbl.minimumScaleFactor          = 0.4
            self.primaryInstruction_lbl.adjustsFontSizeToFitWidth   = true;
            
            //distanceInstruction_lbl
            self.distanceInstruction_lbl.distanceInstructionStyle()

            //gps_lbl
            self.gpsSignl_lbl.title3Style()
            
            //containerBannerView
            //self.containerBanner_view.layer.cornerRadius = 30
            if(self.whiteLabel?.isWhiteLabel ?? false) {
                self.containerBanner_view.backgroundColor = UIColor(hex: "#28353DFF")
            } else {
                self.containerBanner_view.backgroundColor = Style.shared.primaryColor
            }

            self.statusBarBanner_view.backgroundColor = Style.shared.primaryColor
            
            //containerSeconcBannerView
            self.containerSecondBanner_view.layer.cornerRadius = 30
            
            //containerMap_view
            self.containerMap_view.backgroundColor = Style.shared.backgroundColor
            
            // containerView_view
            self.containerView_view.backgroundColor = Style.shared.backgroundColor
            
            // informationsContainer_view
            self.informationsContainer_view.backgroundColor = Style.shared.backgroundColor
            self.informationsContainer_view.layer.cornerRadius = 30
            
            // pauseRun_slideBtn
            self.pauseRun_slideBtn.myView = self.dotSlide_view
            self.pauseRun_slideBtn.buttonUnlockedText = "UNLOCKED"
            self.pauseRun_slideBtn.delegate = self
            
            //dotSlide_view
            self.dotSlide_view.layer.cornerRadius = 40
            self.dotSlide_view.layer.borderWidth = 15

            if(self.whiteLabel?.isWhiteLabel ?? false) {
                self.dotSlide_view.backgroundColor = UIColor(hex: self.gpsColor+"FF")
                self.dotSlide_view.layer.borderColor = UIColor(hex: self.gpsColor+"FF")?.lighter(by: 30)?.cgColor
            } else {
                  self.dotSlide_view.backgroundColor = Style.shared.slideDotColor
                  self.dotSlide_view.layer.borderColor = Style.shared.slideDotBorderColor.cgColor//
            }

            self.dotSlide_view.isUserInteractionEnabled = false
            
            // dotIcon_imageView
            self.dotIcon_imageView.image = Bundle.assets.image(named: "pause_icon")
            
            //progressRouteIcon_imageView
            self.progressRouteIcon_imageView.image = Bundle.assets.image(named: "thumbeilslider")
            
            // progressRoute_ProgressBar
            self.progressRoute_ProgressBar.trackTintColor = Style.shared.slideBackgroundColor
            
            // Labels
            if(self.whiteLabel?.isWhiteLabel ?? false) {
                self.timerValue_lbl.font = Style.shared.timerCardFont
                self.timerValue_lbl.textColor = UIColor(hex: self.gpsColor+"FF")
            } else {
                 self.timerValue_lbl.timerCradStyle()
            }

            
            self.speedValue_lbl.valueCradStyle()
            self.distanceValue_lbl.valueCradStyle()
            
            self.speedTitle_lbl.titleCradStyle()
            self.distanceTitle_lbl.titleCradStyle()
            
            //center_btn
            self.center_btn.layer.cornerRadius                      = 20
            self.center_btn.backgroundColor                         = UIColor(hex: self.gpsColor+"FF")
            let origImage = UIImage(named: "ic_gps_center")
            let tintedImage = origImage?.withRenderingMode(.alwaysTemplate)
            self.center_btn.setImage(tintedImage, for: .normal)
            self.center_btn.tintColor = UIColor.white
            
            if self.measurementSystem == .metric
            {
                self.speedTitle_lbl.text                            = "km/h"
                self.distanceTitle_lbl.text                         = "km"
            }
            else if self.measurementSystem == .imperial
            {
                self.speedTitle_lbl.text                            = "mph"
                self.distanceTitle_lbl.text                         = "mi"
            }
            self.initFloatingButtons()
        }
    }


    func initFloatingButtons() -> Void
    {
        let customCellFactory: (String,String) -> LiquidFloatingCell = { (iconName,title) in
            var color = Style.shared.primaryColor
            if(self.whiteLabel?.isWhiteLabel ?? false) {
                color = UIColor(hex: self.gpsColor+"FF")!
            }

            let cell = CustomCell(icon: Bundle.assets.image(named: iconName)!, name: title, textColor: color)
            return cell
        }

        cellsFloatingButton.append(customCellFactory("ic_sound_on", "Audio guide: activated"))
        cellsFloatingButton.append(customCellFactory("sms_ic", "Emergency SMS"))
        //cellsFloatingButton.append(cellFactory("ic_place"))


        let _: (CGRect, LiquidFloatingActionButtonAnimateStyle) -> LiquidFloatingActionButton = { (frame, style) in
            let floatingActionButton = CustomDrawingActionButton(frame: frame)
            floatingActionButton.animateStyle = style
            floatingActionButton.delegate = self
            var buttonColor = Style.shared.primaryColor
            if(self.whiteLabel?.isWhiteLabel ?? false) {
               buttonColor = UIColor(hex: self.gpsColor+"FF")!
            }
            floatingActionButton.color = buttonColor
            return floatingActionButton
        }

        DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+1) {
            let createButton: (CGRect, LiquidFloatingActionButtonAnimateStyle) -> LiquidFloatingActionButton = { (frame, style) in
                let floatingActionButton = CustomDrawingActionButton(frame: frame)
                floatingActionButton.animateStyle = style
                floatingActionButton.dataSource = self
                floatingActionButton.delegate = self

                var buttonColor = Style.shared.primaryColor
                if(self.whiteLabel?.isWhiteLabel ?? false) {
                    buttonColor = UIColor(hex: self.gpsColor+"FF")!
                }
                floatingActionButton.color = buttonColor
                return floatingActionButton
            }
            let floatingFrame = CGRect(x: self.containerMap_view.frame.width - 56 - 16, y: self.containerMap_view.frame.height - 56 - 16 - 30, width: 56, height: 56)
            
            self.more_btn = createButton(floatingFrame, .up)
            
            let image = UIImage(named: "more_ic")
            self.more_btn.image = image
            self.containerMap_view.addSubview(self.more_btn)
        }

        

         if let stringUrl = routeInformation?.city?.spotifyURL {
            if URL.init(string: stringUrl) != nil
                       {
 
                        DispatchQueue.main.async {
                            var buttonColor = Style.shared.primaryColor
                            if(self.whiteLabel?.isWhiteLabel ?? false) {
                                buttonColor = UIColor(hex: self.gpsColor+"FF")!
                            }
                            self.fab = MDCFloatingButton()
                            self.fab?.frame =  CGRect(x: self.containerMap_view.frame.width - 45 - 16 , y: self.containerMap_view.frame.height - 45 - 35 - 65 , width: 45, height: 45)
                            self.fab?.inkColor = buttonColor
                            self.fab?.backgroundColor = .white
                            self.fab?.tintColor = buttonColor
                            self.fab?.setImage(UIImage(named: "ic_music"), for: .normal)
                            self.fab?.addTarget(self, action: #selector(self.sponsor_action(_:)), for: .touchUpInside)
                            self.containerMap_view.addSubview(self.fab!)
                        }
            }
        }
    }
    
    @objc func sponsor_action(_ sender: UIButton) {
        showSpotify()
    }
    
    func initMap() -> Void {
        DispatchQueue.main.async {
            if let location = LocationService.shared.getCurrentLocation()
            {
                self.mapView_map.setCenter(location.coordinate, zoomLevel: 17, direction: 0, animated: false)
            }
            self.mapView_map.delegate                               = self
            self.mapView_map.compassView.isHidden                   = true
            self.mapView_map.logoView.isHidden                      = true
            self.mapView_map.attributionButton.isHidden             = true
            self.mapView_map.showsUserLocation                      = true
            self.mapView_map.tracksUserCourse                       = false
            self.mapView_map.userTrackingMode                       = .followWithHeading
        }
    }
    
    func initLocationManager() -> Void {
        LocationService.shared.locationManager.delegate             = self
        LocationService.shared.locationManager.requestWhenInUseAuthorization()
        LocationService.shared.locationManager.activityType         = .fitness
        LocationService.shared.locationManager.desiredAccuracy      = 10
        LocationService.shared.locationManager.distanceFilter = kCLDistanceFilterNone
        LocationService.shared.locationManager.startUpdatingLocation()
        LocationService.shared.locationManager.startMonitoringSignificantLocationChanges()
        
    }
    
    func initMeasurementSystem() -> Void{
        if measurementSystem == .imperial {
            NavigationSettings.shared.distanceUnit = .mile
        } else if measurementSystem == .metric {
            NavigationSettings.shared.distanceUnit = .kilometer
        }
    }
    
    func initLanguageRessources() {
        if  let arraySaved = UserDefaults.standard.array(forKey: "languagePreferredOrder") as! Array<String>? {
            languageRessource = LanguageRessource.init(languageSelected: arraySaved.first!)
        } else {
            languageRessource = LanguageRessource.init(languageSelected: MyUtils.getLanguage())
        }
    }
    
    func initAudioSpeech() -> Void {
        PlayerManager.shared.configureSession(lang:  languageAndCountry)
    }
    
    func initNavigation(userRoute:Route) -> Void {

        if navigationFinished  == false {
            navigationService = MapboxNavigationService.init(route: userRoute)
            RouteControllerProactiveReroutingInterval = 500
            navigationService.router.reroutesProactively = false
            navigationService.delegate = self
            initVoiceController()
            resumeNotifications()
            navigationService.start()
        }
    }
    
    
    
    func initVoiceController() -> Void {
        voiceController = CustomVoiceController(navigationService: navigationService)
        self.voiceController?.initNotification()
    }
    
    func deinitNavigation() {
        if self.navigationService != nil {
            self.navigationService.stop()
        }
        self.voiceController = nil
        self.suspendNotifications()
       // PlayerManager.shared.stopPlayer()
        navigationFinished  = true
        self.voiceController?.stopPlayer()
        PlayerManager.shared.stopSynt()
        DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+1) {
            if(self.whiteLabel?.isWhiteLabel ?? false && self.whiteLabel?.endInstruction != "") {
                PlayerManager.shared.playSynt(description: self.whiteLabel?.endInstruction ?? "")
            } else {
                PlayerManager.shared.playSynt(description: self.languageRessource.endRoute)
            }
        }
    }
    
    
    func stopNavigation() -> Void {
        suspendNotifications()
        if navigationService != nil {
            navigationService.stop()
            navigationService.delegate = nil
        }

        voiceController = nil
        navigationService = nil
        PlayerManager.shared.speechSynthesizer.stopSpeaking(at: AVSpeechBoundary.immediate)
        wayToRoute = nil
    }
    
}
